=======
History
=======

0.1.9 (2017-05-06)
------------------

Changed
^^^^^^^

* __getitem__ will call __missing__ method if key does not exist

Added
^^^^^

* __missing__ method which returns None
* full documentation of dotty_dict usage

0.1.8 (2017-05-03)
------------------

Changed
^^^^^^^

* Travis YAML configuration compatible with TOX

0.1.0 (2017-05-03)
------------------

Added
^^^^^

* First release on PyPI.
